tlslite.errors.TLSFaultError

Package tlslite :: Module errors :: Class TLSFaultError |
[hide private]
[frames] | no frames]

# Class TLSFaultError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                            TLSError --+
                                       |
                                      TLSFaultError

The other party responded incorrectly to an induced fault.

This exception will only occur during fault testing, when a TLSConnection's fault variable is set to induce some sort of faulty behavior, and the other party doesn't respond appropriately.

Instance Methods | [hide private]
Inherited from `TLSError`: `__str__` Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`